Learn R Programming

overlapptest (version 1.4)

rotawin: Rotate Individual Polygons

Description

Randomly rotates individual polygons around their centroids.

Usage

rotawin(ventana)

Value

rotawin returns the original owin object with the individual polygons randomly rotated.

Arguments

ventana

A multiple-polygon window with the format owin of spatstat.

Author

Marcelino de la Cruz Rot

Details

rotawin applies an independent random rotation to each of the polygons in a multiple-polygon owin object.

Examples

Run this code
data(Astragalus)
plot(Astragalus)
plot(rotawin(Astragalus), add=TRUE, border=2)

Run the code above in your browser using DataLab