powered by
Randomly rotates individual polygons around their centroids.
rotawin(ventana)
rotawin returns the original owin object with the individual polygons randomly rotated.
rotawin
owin
A multiple-polygon window with the format owin of spatstat.
Marcelino de la Cruz Rot
rotawin applies an independent random rotation to each of the polygons in a multiple-polygon owin object.
data(Astragalus) plot(Astragalus) plot(rotawin(Astragalus), add=TRUE, border=2)
Run the code above in your browser using DataLab